# `relationalai.Producer.__rtruediv__().md`

```python
relationalai.Producer.__rtruediv__(other: Any) -> Expression
```

Returns an [`Expression`](../Expression.md) that produces the quotient of the [`Producer`](./README.md) values and `other`.
`.__rtruediv__()` is implemented so that you may use a non-`Producer` object as the left operand.

#### See Also

[`Producer.__truediv__()`](./truediv__.md)
